@@ -25,7 +25,6 @@
 load_degrad <- function(dataset = "degrad", raw_data = FALSE,
                         time_period,
                         language = "eng") {
-
   ##############################
   ## Binding Global Variables ##
   ##############################
@@ -42,11 +41,16 @@ load_degrad <- function(dataset = "degrad", raw_data = FALSE,
   #############################
 
   param <- list()
+  param$source <- "degrad"
   param$dataset <- dataset
   param$time_period <- time_period
   param$language <- language
   param$raw_data <- raw_data
 
+  # check if dataset and time_period are valid
+
+  check_params(param)
+
   # .shp file names for each year
 
   file_list <- c(
@@ -75,7 +79,7 @@ load_degrad <- function(dataset = "degrad", raw_data = FALSE,
     function(year, file) {
       external_download(
         dataset = param$dataset,
-        source = "degrad",
+        source = param$source,
         year = year,
         file_name = file
       ) %>%
