@@ -1,14 +1,11 @@
-utils::globalVariables("where") # the selection helper 'where' is not exported from tidyselect, so this must be used to avoid notes
-# they've recently made the move to export it, but it's still not is CRAN
-
 #' @title DETER - Forest Degradation in the Brazilian Amazon
 #'
-#' @description Loads information on changes in forest cover in the Amazon.
+#' @description Loads data on changes in forest cover in the Legal Amazon and the Cerrado biome.
 #'
-#' @param dataset A dataset name ("deter_amz", "deter_cerrado") with information about both Amazon and Cerrado
+#' @param dataset A dataset name ("deter_amz", "deter_cerrado") with information about the Legal Amazon and Cerrado, respectively
 #' @inheritParams load_baci
 #'
-#' @return A \code{tibble} (if \code{raw_data} = \code{TRUE}) or a \code{sf} object (if \code{raw_data} = \code{FALSE}).
+#' @return A \code{sf} object.
 #'
 #' @examples
 #' \dontrun{
@@ -23,12 +20,11 @@ utils::globalVariables("where") # the selection helper 'where' is not exported f
 
 load_deter <- function(dataset, raw_data = FALSE,
                        language = "eng") {
-
   ###########################
   ## Bind Global Variables ##
   ###########################
 
-  .data <- view_date <- name_muni <- code_muni <- sensor <- satellite <- NULL
+  .data <- view_date <- name_muni <- code_muni <- sensor <- satellite <- abbrev_state <- NULL
   uc <- classname <- path_row <- area <- quadrant <- geometry <- id_alerta <- NULL
 
   #############################
@@ -36,17 +32,22 @@ load_deter <- function(dataset, raw_data = FALSE,
   #############################
 
   param <- list()
+  param$source <- "deter"
   param$dataset <- dataset
   param$language <- language
   param$raw_data <- raw_data
 
+  # check if dataset is valid
+
+  check_params(param)
+
   #################
   ## Downloading ##
   #################
 
   dat <- external_download(
     dataset = param$dataset,
-    source = "deter"
+    source = param$source
   )
 
   ## Return Raw Data
@@ -60,9 +61,10 @@ load_deter <- function(dataset, raw_data = FALSE,
   ######################
 
   dat <- dat %>%
+    janitor::clean_names() %>%
     dplyr::mutate(
       dplyr::across(
-        where(is.character),
+        dplyr::where(is.character),
         ~ stringi::stri_trans_general(., id = "Latin-ASCII")
       )
     )
@@ -98,8 +100,8 @@ load_deter <- function(dataset, raw_data = FALSE,
 
   dat <- dat %>%
     dplyr::select(
-      view_date, name_muni, code_muni, sensor, satellite,
-      classname, path_row, area, quadrant, geometry, id_alerta
+      view_date, name_muni, code_muni, abbrev_state,
+      area, geometry, id_alerta
     )
 
   ###################
@@ -112,9 +114,7 @@ load_deter <- function(dataset, raw_data = FALSE,
         "data" = view_date,
         "municipio" = name_muni,
         "cod_municipio" = code_muni,
-        "satelite" = satellite,
-        "classe" = classname,
-        "quadrante" = quadrant
+        "uf" = abbrev_state
       )
   }
 
@@ -124,7 +124,7 @@ load_deter <- function(dataset, raw_data = FALSE,
         "date" = view_date,
         "municipality" = name_muni,
         "municipality_code" = code_muni,
-        "class_name" = classname,
+        "state" = abbrev_state,
         "alert_id" = id_alerta
       )
   }
