@@ -20,7 +20,6 @@
 load_sigmine <- function(dataset = "sigmine_active",
                          raw_data = FALSE,
                          language = "eng") {
-
   ##############################
   ## Binding Global Variables ##
   ##############################
@@ -32,15 +31,20 @@ load_sigmine <- function(dataset = "sigmine_active",
   #############################
 
   param <- list()
+  param$source <- "sigmine"
   param$dataset <- dataset
   param$language <- language
   param$raw_data <- raw_data
 
+  # check if dataset is supported
+
+  check_params(param)
+
   ######################
   ## Downloading Data ##
   ######################
 
-  dat <- external_download(dataset = param$dataset, source = "sigmine") %>%
+  dat <- external_download(dataset = param$dataset, source = param$source) %>%
     janitor::clean_names()
 
   ## Return Raw Data
